---
layout: "vault"
page_title: "Vault: vault_rabbitmq_secret_backend resource"
sidebar_current: "docs-vault-resource-rabbitmq-secret-backend"
description: |-
  Creates an RabbitMQ secret backend for Vault.
---

# vault\_rabbitmq\_secret\_backend

Creates an RabbitMQ Secret Backend for Vault. RabbitMQ secret backends can then issue RabbitMQ credentials,
 once a role has been added to the backend.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_rabbitmq_secret_backend" "rabbitmq" {
  connection_uri = "https://....."
  username = "user"
  password = "password"
}
```

## Argument Reference

The following arguments are supported:

* `connection_uri` - (Required)  Specifies the RabbitMQ connection URI.

* `username` - (Required) Specifies the RabbitMQ management administrator username.

* `password` - (Required) Specifies the RabbitMQ management administrator password.

* `verify_connection` - (Optional) Specifies whether to verify connection URI, username, and password.
Defaults to `true`.


~> **Important** Because Vault does not support reading the configured
credentials back from the API, Terraform cannot detect and correct drift
on `connection_uri`, `username`, `password` or `verify_connection`. Changing the values, however, _will_
overwrite the previously stored values.

* `path` - (Optional) The unique path this backend should be mounted at. Must
not begin or end with a `/`. Defaults to `aws`.

* `description` - (Optional) A human-friendly description for this backend.

* `default_lease_ttl_seconds` - (Optional) The default TTL for credentials
issued by this backend.

* `max_lease_ttl_seconds` - (Optional) The maximum TTL that can be requested
for credentials issued by this backend.

## Attributes Reference

No additional attributes are exported by this resource.

## Import

RabbitMQ secret backends can be imported using the `path`, e.g.

```
$ terraform import vault_rabbitmq_secret_backend.rabbitmq rabbitmq
```
